<?php
namespace Ep\Wp\Plugin;

use _WP_Dependency;
use Zend\Stdlib\ArrayUtils;

/**
 * Omogućava paketima pružanje front-end resursa.
 *
 * @package Ep\Wp\Plugin
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-wordpress
 */
class Assets implements PluginInterface
{
    /** @var array */
    private $config;
    /** @var array */
    private $manifest;

    /**
     * Assets constructor.
     *
     * @param array $config
     */
    public function __construct(array $config)
    {
        $this->config = $config['assets'] ?? [];
    }

    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function __invoke(): void
    {
        add_action('admin_enqueue_scripts', [$this, 'enqueue_scripts'], PHP_INT_MAX);
        add_action('init', [$this, 'init']);
        add_action('wp_enqueue_scripts', [$this, 'enqueue_scripts'], PHP_INT_MAX);
    }

    public function init()
    {
        remove_action('admin_print_scripts','print_emoji_detection_script');
        remove_action('embed_head', 'print_emoji_detection_script');
        remove_action('wp_head','print_emoji_detection_script', 7);
    }

    /**
     * Zamijenjuje urlove skripti s urlovima iz manifesta.
     */
    public function enqueue_scripts()
    {
        global $wp_scripts, $wp_styles;

        $manifest = $this->getManifest();

        foreach ($wp_scripts->registered as $script) {
            /** @var _WP_Dependency $script */
            if ($script->ver === 'ep-asset') {
                if (isset($manifest[$script->src])) {
                    $script->src = $manifest[$script->src];
                }
            }
        }

        foreach ($wp_styles->registered as $style) {
            /** @var _WP_Dependency $style */
            if ($style->ver === 'ep-asset') {
                if (isset($manifest[$style->src])) {
                    $style->src = $manifest[$style->src];
                }
            }
        }
    }

    /**
     * Vraća zmerđani manifest.
     *
     * @return array
     */
    private function getManifest()
    {
        if (null === $this->manifest) {
            $this->manifest = [];

            foreach ($this->config['paths'] ?? [] as $path) {
                $manifestFile = realpath(sprintf('%s/manifest.json', rtrim($path, '/')));

                if (file_exists($manifestFile)) {
                    $manifest = file_get_contents($manifestFile);
                    $manifest = json_decode($manifest, true);

                    foreach ($manifest as $src => $url) {
                        $baseUrl = '//' . $_SERVER['HTTP_HOST'] . preg_replace('#^' . $_SERVER['DOCUMENT_ROOT'] . '#', '', dirname($manifestFile));
                        $manifest[$src] = sprintf('%s/%s', $baseUrl, $url);
                    }

                    $this->manifest = ArrayUtils::merge($this->manifest, $manifest);
                }
            }
        }

        return $this->manifest;
    }
}