<?php
namespace Ep\Wp\Plugin\I18n;

use Ep\Wp\Plugin\PluginInterface;

/**
 * Pretvara prijevode na ćirilici u latinicu.
 *
 * @package Ep\Wp\I18n
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-wordpress
 */
class CyrillicToLatin implements PluginInterface
{
    /** @var array */
    private $replace = [
        "А" => "A",
        "Б" => "B",
        "В" => "V",
        "Г" => "G",
        "Д" => "D",
        "Ђ" => "Đ",
        "Е" => "E",
        "Ж" => "Ž",
        "З" => "Z",
        "И" => "I",
        "Ј" => "J",
        "К" => "K",
        "Л" => "L",
        "Љ" => "Lj",
        "М" => "M",
        "Н" => "N",
        "Њ" => "Nj",
        "О" => "O",
        "П" => "P",
        "Р" => "R",
        "С" => "S",
        "Т" => "T",
        "Ћ" => "Ć",
        "У" => "U",
        "Ф" => "F",
        "Х" => "H",
        "Ц" => "C",
        "Ч" => "Č",
        "Џ" => "Dž",
        "Ш" => "Š",
        "а" => "a",
        "б" => "b",
        "в" => "v",
        "г" => "g",
        "д" => "d",
        "ђ" => "đ",
        "е" => "e",
        "ж" => "ž",
        "з" => "z",
        "и" => "i",
        "ј" => "j",
        "к" => "k",
        "л" => "l",
        "љ" => "lj",
        "м" => "m",
        "н" => "n",
        "њ" => "nj",
        "о" => "o",
        "п" => "p",
        "р" => "r",
        "с" => "s",
        "т" => "t",
        "ћ" => "ć",
        "у" => "u",
        "ф" => "f",
        "х" => "h",
        "ц" => "c",
        "ч" => "č",
        "џ" => "dž",
        "ш" => "š",
    ];

    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function __invoke(): void
    {
        add_filter('gettext', [$this, 'convert'], 9);
        add_filter('gettext_with_context', [$this, 'convert'], 9);
        add_filter('ngettext', [$this, 'convert'], 9);
        add_filter('ngettext_with_context', [$this, 'convert'], 9);
    }

    /**
     * Zamijenjuje ćirilicu latinicom.
     *
     * @param $text
     *
     * @return string
     */
    public function convert($text)
    {
        return strstr($text, $this->replace);
    }
}